@@ -10,8 +10,8 @@ class SupportsWrite(Protocol):
 
 
 def write_csv(target: SupportsWrite, columns: list[DataColumnSchema], rows: Iterable[dict[str, Any]]) -> None:
-    column_titles = [col.title for col in columns]
-    writer = DictWriter(target, fieldnames=column_titles, quoting=QUOTE_MINIMAL)
+    column_names = [col.name for col in columns]
+    writer = DictWriter(target, fieldnames=column_names, quoting=QUOTE_MINIMAL)
     writer.writeheader()
     for row in rows:
         writer.writerow(row)
@@ -21,7 +21,7 @@ def convert_data_for_csv(row: dict[str, Any], columns: list[DataColumnSchema]) -
     prepared_row = {}
 
     for col in columns:
-        value = row[col.title]
+        value = row[col.name]
 
         if col.type == ColumnType.BOOL:
             value = bool(value)
@@ -33,7 +33,7 @@ def convert_data_for_csv(row: dict[str, Any], columns: list[DataColumnSchema]) -
         elif col.type == ColumnType.DATE:
             value = value.strftime(DATE_FORMAT)
 
-        prepared_row[col.title] = str(value)
+        prepared_row[col.name] = str(value)
 
     return prepared_row
 
