@@ -30,7 +30,7 @@ class AggregationType(str, Enum):
 
 @dataclass
 class DataColumnSchema:
-    title: str
+    name: str
     type: ColumnType  # noqa: A003
     kind: ColumnKind
     agg: AggregationType
